from .accounts import Accounts
from .aos_contracts import AosContracts
from .aos_invoices import AosInvoices
from .aos_pdf_templates import AosPdfTemplates
from .aos_product_categories import AosProductCategories      
from .aos_products import AosProducts
from .aos_quotes import AosQuotes
from .appointments import Appointments
from .approval import Approval
from .asol_project import AsolProject
from .branches import Branches
from .bugs import Bugs
from .calls import Calls
from .cases import Cases
from .communications import Communications
from .communications_target import CommunicationsTarget       
from .communications_template import CommunicationsTemplate   
from .campaigns import Campaigns
from .contacts import Contacts
from .deposits import Deposits
from .documents import Documents
from .emails import Emails
from .knowledge_base import KnowledgeBase
from .knowledge_base_categories import KnowledgeBaseCategories
from .leads import Leads
from .meetings import Meetings
from .notes import Notes
from .obj_conditions import ObjConditions
from .obj_indicators import ObjIndicators
from .obj_objectives import ObjObjectives
from .opportunities import Opportunities
from .payments import Payments
from .purchase_order import PurchaseOrder
from .sc_competitor import ScCompetitor
from .sc_contract import ScContract
from .sc_contract_management import ScContractManagement
from .service_centers import ServiceCenters
from .tasks import Tasks
from .timesheet import Timesheet
from .vendors import Vendors

__all__ = [
    'Accounts',
    'AosContracts',
    'AosInvoices',
    'AosPdfTemplates',
    'AosProductCategories',
    'AosProducts',
    'AosQuotes',
    'Appointments',
    'Approval',
    'AsolProject',
    'Branches',
    'Bugs',
    'Calls',
    'Cases',
    'Communications',
    'CommunicationsTarget',
    'CommunicationsTemplate',
    'Campaigns',
    'Contacts',
    'Deposits',
    'Documents',
    'Emails',
    'KnowledgeBase',
    'KnowledgeBaseCategories',
    'Leads',
    'Meetings',
    'Notes',
    'ObjConditions',
    'ObjIndicators',
    'ObjObjectives',
    'Opportunities',
    'Payments',
    'PurchaseOrder',
    'ScCompetitor',
    'ScContract',
    'ScContractManagement',
    'ServiceCenters',
    'Tasks',
    'Timesheet',
    'Vendors',
]