from typing import LiteralString

SarvAPI_v5: LiteralString = 'https://app.sarvcrm.com/API.php'
SarvFrontend: LiteralString = 'https://app.sarvcrm.com/index.php'

SarvURL = SarvAPI_v5

__all__ = [
    'SarvAPI_v5',
    'SarvFrontend',
    'SarvURL',
]